@@ -1,6 +1,6 @@
 /*
 
-  $Id: gsm-api.c,v 1.64 2003/03/06 21:23:56 pkot Exp $
+  $Id: gsm-api.c,v 1.66 2004/05/08 20:52:39 bozo Exp $
 
   G N O K I I
 
@@ -134,6 +134,7 @@ API gn_error gn_gsm_initialise(struct gn_statemachine *sm)
 	dprintf("smsc_timeout: %d\n", sm->config.smsc_timeout);
 	dprintf("connect_script: %s\n", sm->config.connect_script);
 	dprintf("disconnect_script: %s\n", sm->config.disconnect_script);
+	dprintf("rfcomm_cn: %d\n", (int)sm->config.rfcomm_cn);
 
 	if (sm->config.model[0] == '\0') return GN_ERR_UNKNOWNMODEL;
 	if (sm->config.port_device[0] == '\0') return GN_ERR_FAILED;
@@ -150,6 +151,7 @@ API gn_error gn_gsm_initialise(struct gn_statemachine *sm)
 	REGISTER_DRIVER(fake, NULL);
 	REGISTER_DRIVER(at, sm->config.model);
 	REGISTER_DRIVER(nokia_6160, NULL);
+	REGISTER_DRIVER(gnapplet, NULL);
 
 	return GN_ERR_UNKNOWNMODEL;
 }
