@@ -1,6 +1,6 @@
 /*
 
-  $Id: gsm-encoding.c,v 1.57 2004/02/22 20:00:55 uid66849 Exp $
+  $Id: gsm-encoding.c,v 1.59 2004/07/04 14:11:38 pkot Exp $
 
   G N O K I I
 
@@ -44,6 +44,13 @@
 #ifdef HAVE_LANGINFO_CODESET
 #  include <langinfo.h>
 #endif
+#ifdef HAVE_LOCALE_CHARSET
+#  include <libcharset.h>
+#else
+/* FIXME: We should include here somehow ../intl/localcharset.h, but it may
+ * cause problems with MSVC. */
+extern const char *locale_charset(void); /* from ../intl/localcharset.c */
+#endif
 
 static const char *base64_alphabet = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 
@@ -78,7 +85,6 @@ static unsigned char gsm_default_alphabet[GN_CHAR_ALPHABET_SIZE] = {
 
 static unsigned char gsm_reverse_default_alphabet[256];
 static bool reversed = false;
-extern const char *locale_charset(void); /* from ../intl/localcharset.c */
 
 static void tbl_setup_reverse()
 {
@@ -587,12 +593,13 @@ static const char *get_langinfo_codeset(void)
 }
 
 /* UTF-8 conversion functions */
-int utf8_decode(char *outstring, int outlen, const char *instring, int inlen)
+int utf8_decode(char *outstring, size_t outlen, const char *instring, size_t inlen)
 {
 	size_t nconv;
 
 #if defined(HAVE_ICONV)
-	char *pin, *pout;
+	ICONV_CONST char *pin;
+	char *pout;
 	iconv_t cd;
 
 	pin = (char *)instring;
@@ -645,7 +652,8 @@ int utf8_encode(char *outstring, int outlen, const char *instring, int inlen)
 {
 #if defined(HAVE_ICONV)
 	size_t outleft, inleft, nconv;
-	char *pin, *pout;
+	ICONV_CONST char *pin;
+	char *pout;
 	iconv_t cd;
 
 	outleft = outlen;
