@@ -1,6 +1,6 @@
 /*
 
-  $Id: atbus.c,v 1.38 2003/10/28 00:03:40 bozo Exp $
+  $Id: atbus.c,v 1.42 2004/06/09 13:58:15 bozo Exp $
 
   G N O K I I
 
@@ -122,7 +122,18 @@ char *findcrlfbw(unsigned char *str, int len)
 {
 	while ((*str != '\n') && (*str-1 != '\r') && len--)
 		str--;
-	return len ? str+1 : NULL;
+	return len > 0 ? str+1 : NULL;
+}
+
+int numchar(unsigned char *str, unsigned char ch)
+{
+	int count = 0;
+
+	while (*str && *str != '\r') {
+		if (*str++ == ch) count++;
+	}
+
+	return count;
 }
 
 /* 
@@ -133,6 +144,10 @@ static void atbus_rx_statemachine(unsigned char rx_char, struct gn_statemachine
 {
 	int error;
 	atbus_instance *bi = AT_BUSINST(sm);
+	int unsolicited, count;
+
+	if (!bi)
+		return;
 	
 	bi->rbuf[bi->rbuf_pos++] = rx_char;
 	bi->rbuf[bi->rbuf_pos] = '\0';
@@ -144,6 +159,10 @@ static void atbus_rx_statemachine(unsigned char rx_char, struct gn_statemachine
 	/* first check if <cr><lf> is found at end of reply_buf.
 	 * none: the needed length is greater 4 because we don't
 	 * need to enter if no result/error will be found. */
+	if (bi->rbuf_pos == 3 && !strcmp(bi->rbuf + 1, "\r\n")) {
+		bi->rbuf_pos = 1;
+		bi->rbuf[1] = '\0';
+	}
 	if (bi->rbuf_pos > 4 && !strncmp(bi->rbuf + bi->rbuf_pos - 2, "\r\n", 2)) {
 		/* try to find previous <cr><lf> */
 		char *start = findcrlfbw(bi->rbuf + bi->rbuf_pos - 2, bi->rbuf_pos - 1);
@@ -156,10 +175,27 @@ static void atbus_rx_statemachine(unsigned char rx_char, struct gn_statemachine
 		else if (bi->rbuf_pos > 7 && !strncmp(start, "ERROR", 5))
 			bi->rbuf[0] = GN_AT_ERROR;
 		/* FIXME: use error codes some useful way */
-		else if (sscanf(start, "+CMS ERROR: %d", &error) == 1)
-			bi->rbuf[0] = GN_AT_ERROR;
-		else if (sscanf(start, "+CME ERROR: %d", &error) == 1)
-			bi->rbuf[0] = GN_AT_ERROR;
+		else if (sscanf(start, "+CMS ERROR: %d", &error) == 1) {
+			bi->rbuf[0] = GN_AT_CMS;
+			bi->rbuf[1] = error / 256;
+			bi->rbuf[2] = error % 256;
+		} else if (sscanf(start, "+CME ERROR: %d", &error) == 1) {
+			bi->rbuf[0] = GN_AT_CME;
+			bi->rbuf[1] = error / 256;
+			bi->rbuf[2] = error % 256;
+		} else if (*start == '+') {
+			/* check for possible unsolicited responses */
+			unsolicited = 0;
+			if (!strncmp(start + 1, "CREG:", 5)) {
+				count = numchar(start, ',');
+				if (count == 0 || count == 2) unsolicited = 1;
+			} else if (!strncmp(start + 1, "CPIN:", 5))
+				bi->rbuf[0] = GN_AT_OK;
+			if (unsolicited) {
+				*start = '\0';
+				bi->rbuf_pos = start - bi->rbuf;
+			}
+		}
 	}
 	/* check if SMS prompt is found */
 	if (bi->rbuf_pos > 4 && !strncmp(bi->rbuf + bi->rbuf_pos - 4, "\r\n> ", 4))
@@ -190,8 +226,9 @@ static gn_error atbus_loop(struct timeval *timeout, struct gn_statemachine *sm)
 	res = device_select(timeout, sm);
 	if (res > 0) {
 		res = device_read(buffer, 255, sm);
-		for (count = 0; count < res; count++)
+		for (count = 0; count < res; count++) {
 			atbus_rx_statemachine(buffer[count], sm);
+		}
 	} else
 		return GN_ERR_TIMEOUT;
 	/* This traps errors from device_read */
@@ -210,6 +247,9 @@ gn_error atbus_initialise(int mode, struct gn_statemachine *state)
 	gn_error error = GN_ERR_NONE;
 	atbus_instance *businst;
 
+	if (!state)
+		return GN_ERR_FAILED;
+
 	if (!(businst = malloc(sizeof(atbus_instance))))
 		return GN_ERR_FAILED;
 
@@ -242,7 +282,6 @@ gn_error atbus_initialise(int mode, struct gn_statemachine *state)
 		error = GN_ERR_FAILED;
 		goto err;
 	}
-
 	goto out;
 err:
 	dprintf("AT bus initialization failed (%d)\n", error);
