@@ -1,6 +1,6 @@
 /*
 
-  $Id: gnokii.h,v 1.67 2004/02/20 11:02:25 uid66849 Exp $
+  $Id: gnokii.h,v 1.72 2004/06/17 19:05:43 pkot Exp $
 
   G N O K I I
 
@@ -57,6 +57,15 @@ typedef unsigned char uint8_t;
 #  endif
 #endif
 
+#define LIBGNOKII_VERSION_STRING "2.1.0"
+#define LIBGNOKII_VERSION_MAJOR 2
+#define LIBGNOKII_VERSION_MINOR 1
+#define LIBGNOKII_VERSION_RELEASE 0
+#define LIBGNOKII_MAKE_VERSION( a,b,c ) (((a) << 16) | ((b) << 8) | (c))
+
+#define LIBGNOKII_VERSION \
+  LIBGNOKII_MAKE_VERSION(LIBGNOKII_VERSION_MAJOR,LIBGNOKII_VERSION_MINOR,LIBGNOKII_VERSION_RELEASE)
+
 struct gn_statemachine;
 
 #include <gnokii/error.h>
@@ -78,7 +87,7 @@ extern API struct gn_cfg_header *gn_cfg_info;
 /* Files */
 API int gn_file_text_save(char *filename, char *text, int mode);
 /* reads internal gnokii raw phonebook format */
-API gn_error gn_file_phonebook_raw(gn_phonebook_entry *entry, char *buffer);
+API gn_error gn_file_phonebook_raw_parse(gn_phonebook_entry *entry, char *buffer);
 
 /* Misc */
 API gn_memory_type gn_str2memory_type(const char *s);
@@ -91,21 +100,32 @@ API gn_error gn_gsm_initialise(struct gn_statemachine *sm);
 
 /* Config file */
 API char *gn_cfg_get(struct gn_cfg_header *cfg, const char *section, const char *key);
-API int gn_cfg_read(char **bindir);
+API int gn_cfg_read(char **bindir); /* DEPRECATED */
+API int gn_cfg_file_read(const char *filename);
+API int gn_cfg_read_default();
 API int gn_cfg_phone_load(const char *iname, struct gn_statemachine *state);
 
+/* In/Out routines, file formats */
 API int gn_phonebook2vcard(FILE *f, gn_phonebook_entry *entry, char *location);
 API int gn_vcard2phonebook(FILE *f, gn_phonebook_entry *entry);
 
 API int gn_phonebook2ldif(FILE *f, gn_phonebook_entry *entry);
 API int gn_ldif2phonebook(FILE *f, gn_phonebook_entry *entry);
 
+/* DEPRECATED */
 API int gn_vcal_file_event_read(char *filename, gn_calnote *cnote, int number);
 API int gn_vcal_file_todo_read(char *filename, gn_todo *ctodo, int number);
 
+API int gn_calnote2ical(FILE *f, gn_calnote *calnote);
+API int gn_ical2calnote(FILE *f, gn_calnote *calnote, int id);
+
+API int gn_todo2ical(FILE *f, gn_todo *ctodo);
+API int gn_ical2todo(FILE *f, gn_todo *ctodo, int id);
+
 API void gn_number_sanitize(char *number, int maxlen);
 API void gn_phonebook_entry_sanitize(gn_phonebook_entry *entry);
 
+/* Debugging */
 extern API gn_log_target gn_log_debug_mask;
 extern API gn_log_target gn_log_rlpdebug_mask;
 extern API gn_log_target gn_log_xdebug_mask;
