@@ -1,6 +1,6 @@
 /*
 
-  $Id: config.h,v 1.17 2004/04/13 12:39:45 pkot Exp $
+  $Id: config.h,v 1.23 2004/07/04 22:06:48 pkot Exp $
 
   G N O K I I
 
@@ -40,7 +40,7 @@
 
 	
 #undef VERSION
-#define VERSION "0.6.1"
+#define VERSION "0.6.3"
 
 /* No bluetooth and no IRDA */
 #undef HAVE_BLUETOOTH
@@ -58,6 +58,9 @@
 #undef HAVE_UNISTD_H
 #define HAVE_CTYPE_H 1
 #define HAVE_STDLIB_H 1
+#define HAVE_DIRECT_H 1
+#define HAVE_LIMITS_H 1
+#define HAVE_SYS_STAT_H 1
 
 /* Define if your compiler supports long long */
 #undef HAVE_LONG_LONG
@@ -101,11 +104,6 @@
 #define XDEBUG 1
 #define RLP_DEBUG 1
 
-/* Define debug level */
-#ifdef _DEBUG
-#   define	DEBUG
-#endif
-
 /* Decide if you want security options enabled */
 #define SECURITY
 
